<?php
/**
 * Plugin Name: Counter Visitor for Woocommerce
 * Description: Show number of visitors view a product on Woocommerce
 * Version: 1.0.7
 * Donate link: https://paypal.me/taxarpro
 * Author: TaxarPro
 * Author URI: https://taxarpro.com
 * Text Domain: counter-visitor-for-woocommerce
 * Domain Path: /languages
 * License: GPLv2 or later
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 */

if(!defined('ABSPATH')) { exit; }

define('WCVisitor_PATH', dirname(__FILE__).'/');
define('WCVisitor_USE_JS', get_option('_wcv_use_js', '0'));
$uploaddir = wp_upload_dir();
define('WCVisitor_TEMP_FILES', $uploaddir['basedir'] . '/wcvtemp/');
define('WCVisitor_POSITION_SHOW', get_option('_wcv_position', 'woocommerce_after_add_to_cart_button'));

require_once WCVisitor_PATH . 'includes/class.api.php';

if( !class_exists( 'WCVisitor_MAIN' ) ) {
    class WCVisitor_MAIN {


        public $positions = array(
            'woocommerce_after_add_to_cart_button' => 'form.cart|inside',
            'woocommerce_before_add_to_cart_button' => 'form.cart|before',
            'woocommerce_product_meta_end' => 'div.product_meta|after',
            'woocommerce_before_single_product_summary' => 'div.woocommerce-notices-wrapper|after',
            'woocommerce_after_single_product_summary' => 'div.woocommerce-tabs|after',
            'woocommerce_product_thumbnails' => 'div.woocommerce-product-gallery|inside',
        );
    
        function __construct(){
            
            add_action('init', array($this, 'wcvisitor_init'));
            add_action('woocommerce_before_single_product', array($this, 'wcvisitor_record'));
            if(WCVisitor_USE_JS == '0') {
                add_action(WCVisitor_POSITION_SHOW, array($this, 'wcvisitor_show'));
            }else{
                add_action( 'wp_enqueue_scripts', array($this, 'WCVisitor_load_style') );
                add_action( 'wp_footer', array($this, 'wcvisitor_show_js'), 99 );
            }
            add_action('admin_menu', array($this, 'wcvisitor_menu'));
            add_action('plugins_loaded', array($this, 'wcvisitor_load_textdomain'));

        }
        function WCVisitor_load_style() {
            if(is_product() === false) { return; }
            wp_enqueue_script( 'wcvisitor-scripts', plugins_url('assets/scripts.js?wcvisitor=true', __FILE__), array('jquery'));

            wp_localize_script( 'wcvisitor-scripts', 'WCVisitorConfig', array(
                'url'    => admin_url( 'admin-ajax.php' )
            ) );
        }

        function wcvisitor_load_textdomain(){
            load_plugin_textdomain( 'counter-visitor-for-woocommerce', false, dirname( plugin_basename(__FILE__) ) . '/languages' );
        }
        /**
         * wcvisitor_init
         * Genera la estructura si no existe necesaria para el funcionamiento del plugin
         * @return void
         */
        function wcvisitor_init() {
            if(is_admin()) {
                if (!is_dir(WCVisitor_TEMP_FILES)) {
                    mkdir(WCVisitor_TEMP_FILES);
                }
                if ($this->wcvisitor_is_empty_directory(WCVisitor_TEMP_FILES)) {
                    $folderName = 'users_'.wp_generate_password(8, false);
                    update_option('_WCVisitor_folder_name', $folderName);
                    mkdir(WCVisitor_TEMP_FILES .$folderName);
                    $file = fopen(WCVisitor_TEMP_FILES .$folderName.'/index.php',"w");
                    echo fwrite($file,"");
                    fclose($file);
                }
            }
        }

        function wcvisitor_menu() {
            add_submenu_page('woocommerce',__('Counter Visitor','counter-visitor-for-woocommerce'),__('Counter Visitor','counter-visitor-for-woocommerce') , 'manage_options', 'wcvisitor-options', array($this, 'wcvisitor_view_page_options') , plugins_url('/images/icon.png', __FILE__) );
        }

        function wcvisitor_view_page_options() {
            require_once(WCVisitor_PATH . 'views/options.php');
        }
        /**
         * wcvisitor_is_empty_directory
         * 
         * Comprueba si un directorio está vacio o no.
         * 
         * @param string $dir
         * @return boolean
         */
        private function wcvisitor_is_empty_directory($dir) {
            if (!is_readable($dir)) return NULL;
            return (count(scandir($dir)) == 2);
        }
        /**
         * wcvisitor_getIP
         * Retorna la IP del usuario
         * @return void
         */
        private function wcvisitor_getIP() {
            if(isset($_SERVER['HTTP_X_FORWARDED_FOR'])){
                    $ip=$_SERVER['HTTP_X_FORWARDED_FOR'];
                    return $ip;
            }
            if(isset($_SERVER['REMOTE_ADDR'])){
                    $ip = $_SERVER['REMOTE_ADDR'];
                    return $ip;
            }
            return "0.0.0.0";
        }

        function wcvisitor_record() {
            global $post;
            $folderName = WCVisitor_TEMP_FILES . get_option('_WCVisitor_folder_name');
            $ip = $this->wcvisitor_getIP();
            if (!is_dir($folderName .'/' . $post->ID)) {
                mkdir($folderName .'/' . $post->ID);
            }
            file_put_contents ($folderName .'/' . $post->ID .'/' . $ip . '.txt', "0");
            
        }

        function wcvisitor_show_js() {
            if(is_product() === false) { return; }
            global $post;
            $selectPosition = explode('|', $this->positions[WCVisitor_POSITION_SHOW]);
            echo '<script>jQuery(document).ready(function($) { WCVisitor.show('.$post->ID.',\''.json_encode($selectPosition).'\'); });</script>';
        }
        private function wcvisitor_get_block($product) {
            $actualtime=date("U");
            $timeold= get_option('_wcv_timeout_limit',300);
            $folderName = WCVisitor_TEMP_FILES . get_option('_WCVisitor_folder_name') . '/' . $product . '/';
            $counter=0;
            $dir = dir($folderName);
            while($temp = $dir->read()){
                if ($temp=="." or $temp==".."){continue;}
                $filecreatedtime=date("U", filemtime($folderName.$temp));
                if ($actualtime>($filecreatedtime+$timeold)){
                        unlink ($folderName.$temp);
                }else{
                        $counter++;
                }
            }
            if($counter > 1) {
                $msg = get_option('_wcv_message', __('%n people are viewing this product'));
                $msg = str_replace('%n',$counter, $msg);
            }else{
                $msg = get_option('_wcv_message_one', __('1 user are viewing this product'));
                
            }
            $icon = get_option('_wcv_icon','dashicons dashicons-visibility');
            return '<div class="wcv-message wcv-product-'.$product.'"><span class="icon"><i class="'.$icon.'"></i></span>'.$msg.'</div>';
        }
        function wcvisitor_show() {
            global $post;
            $product = $post->ID;
            echo $this->wcvisitor_get_block($product);
        }
        function wcvisitor_show_api($product) {
            return $this->wcvisitor_get_block($product);                
        }


    }

    $WCVISITOR_MAIN = new WCVisitor_MAIN();
}

?>